@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from email.mime import image
 import os,uuid
+from pickle import TRUE
 from posixpath import split
 import sys
 import json
@@ -27,11 +28,15 @@ class Define():
 	class containers():
 		class imagePullPolicy():
 			IfNotPresent = 'IfNotPresent'
+			Always = 'Always'
+			Never ='Never'
 	class dnsPolicy():
 		ClusterFirst = 'ClusterFirst'
 	class Service():
 		ClusterIP = 'ClusterIP'
 		LoadBalancer = 'LoadBalancer'
+		ExternalName = 'ExternalName'
+		NodePort = 'NodePort'
 		class externalTrafficPolicy:
 			Local = 'Local'
 			Cluster = 'Cluster'
@@ -653,7 +658,9 @@ class Service(Common):
 				# for v in value :
 					# Service.service[Service.components]['spec']['ports'].append(v)
 			return self
-
+		def externalName(self, value):
+			Service.service[Service.components]['spec']['externalName'] = value
+			return self
 		def externalIPs(self, value):
 			Service.service[Service.components]['spec']['externalIPs'] = value
 			return self
@@ -944,8 +951,9 @@ class Compose(Logging):
 		if not path:
 			path = self.workload + '.yaml'
 		path = os.path.expanduser(path)
-		# if os.path.exists(path):
-		# os.remove(path)
+		directory = os.path.dirname(path)
+		if not os.path.exists(directory):
+			os.makedirs(directory,exist_ok=True)
 		with open(path, 'w') as file:
 			file.write('---\n'.join(self.compose))
 
@@ -972,7 +980,7 @@ class Kubernetes(Logging):
 		super().__init__()
 		self.environments = {}
 		self.kubernetes = {}
-		self.workspace = '/tmp'
+		self.workspace = '~/.netkiller'
 		if kubeconfig :
 			self.kubeconfig(kubeconfig) 
 
@@ -1045,11 +1053,18 @@ class Kubernetes(Logging):
 			self.environments = name
 		else:	
 			self.environments[name] = kubeconfig
-		# self.logging.info("kubeconfig : %s => %s" % (name,kubeconfig))
+		self.logging.info("kubeconfig : %s => %s" % (name,kubeconfig))
 		return self
 	def save(self, item):
+		directory = self.workspace
+		if self.options.environment:
+			directory = self.workspace + '/' + self.options.environment
+
+		if not os.path.exists(directory):
+			os.makedirs(directory)
+
 		if item in self.kubernetes.keys():
-			path = os.path.expanduser(self.workspace + '/' + item + '.yaml')
+			path = os.path.expanduser(directory + '/' + item + '.yaml')
 			if os.path.exists(path):
 				os.remove(path)
 			self.logging.info('save as %s' % path)
@@ -1125,12 +1140,6 @@ class Kubernetes(Logging):
 		self.logging.info("namespace={namespace}, {project}={image}".format(namespace=namespace, project=project, image=image))
 		self.logging.debug('upgrade %s ' % cmd)
 		self.execute(cmd)
-		# exit()
-
-	# def kubeNamespace(self):
-	#     cmd = "get namespace"
-	#     self.logging.info(cmd)
-	#     self.execute(cmd)
 
 	def service(self):
 		cmd = "get service"
@@ -1161,10 +1170,8 @@ class Kubernetes(Logging):
 		elif self.options.environment and self.options.environment in self.environments:
 			self.kubeconfig(self.environments[self.options.environment])
 		else:
-			# print( "" )
 			for key,value in self.environments.items():
 				print( "%s => %s" % (key,value) )
-			# return
 
 		if self.options.list:
 			self.list()
